@@ -11,7 +11,7 @@ use Tk;
 use CVS::Metrics;
 
 my %opts;
-getopts('f:hst:DHS:', \%opts);
+getopts('f:hst:vDHS:', \%opts);
 
 if ($opts{h}) {
 	print "Usage: $0 [-h] [-f file.log] [-s] [-t title] [-D] [-H] [-S \"yyyy/mm/dd\"]\n";
@@ -19,12 +19,19 @@ if ($opts{h}) {
 	print "\t-f file.log : off-line mode\n";
 	print "\t-s : use an extern style sheet\n";
 	print "\t-t title\n";
+	print "\t-v : version\n";
 	print "\t-D : suppress 'dead' files in tree\n";
 	print "\t-H : append HEAD as a tag\n";
 	print "\t-S start_date : yyyy/mm/dd \n";
 	exit(0);
 }
 
+if ($opts{v}) {
+	print "$0\n";
+	print "CVS::Metrics Version $CVS::Metrics::VERSION\n";
+	exit(0);
+}
+
 my $cfg = ".cvs_metrics";
 our ($title, $regex_tag, $flg_head, $flg_dead, $flg_css, $start_date);
 if ( -r $cfg) {
@@ -158,15 +165,19 @@ if ($parser) {
 	my $cvs_log = $parser->parse($cvs_logfile);
 
 	my @tags;
-	my @tagname = $cvs_log->getTagname();
-	foreach my $tag (sort @tagname) {
+	my $timed = $cvs_log->getTimedTag();
+	my %matched;
+	while (my ($tag, $date) = each %{$timed}) {
 		print "Tag: ", $tag;
 		if ($tag =~ /$regex_tag/) {
-			push @tags, $tag;
+			$matched{$date} = $tag;
 			print " ... matched";
 		}
 		print "\n";
 	}
+	foreach (sort keys %matched) {
+		push @tags, $matched{$_};
+	}
 
 	if ($flg_head) {
 		push @tags, "HEAD";
@@ -189,7 +200,12 @@ sub FindCvs {
 		$cvs = $cvs_setting->{'/P_WhichCvs'};
 		if (defined $cvs) {
 			$cvs =~ s/[\000\001]//g;
-			$cvs =~ s/wincvs\.exe\@$/cvs.exe/;
+			$cvs =~ s/wincvs\.exe\@$//;
+			if ( -e "${cvs}CVSNT\\\\cvs.exe") {
+				$cvs .= "CVSNT\\\\cvs.exe";
+			} else {
+				$cvs .= "cvs.exe";
+			}
 		}
 	}
 
@@ -329,6 +345,7 @@ my $style = q{
 	my $generator = "cvs_tklog " . $CVS::Metrics::VERSION . " (Perl " . $] . ")";
 	my $dir = $path eq "." ? "all" : $path;
 	my $title_full = "${title}_${dir}_${tag_from}_to_${tag_to}";
+	$title_full =~ s/\//_/g;
 
 	my $image = $cvs_log->EnergyGD($tags, $path, $dir, 600, 400, $tag_from, $tag_to);
 
@@ -449,7 +466,7 @@ my $style = q{
 			style		=> $style,
 			generator	=> $generator,
 			date		=> $now,
-			title		=> ${title_full},
+			title		=> $title_full,
 			e_img		=> $e_img,
 			a_img		=> $a_img,
 			timed_tag	=> \@timed_tag,
@@ -637,8 +654,16 @@ sub _upd_img {
 sub _audit {
 	my $self = shift;
 
-	if (        $self->{tag_to} ne 'HEAD'
-			and $self->{tag_from} ge $self->{tag_to} ) {
+	my @tags = @{$self->{tags}};
+	while ($self->{tag_from} ne $tags[0]) {
+		shift @tags;
+	}
+	shift @tags;
+	my $found = 0;
+	foreach (@tags) {
+		$found = 1 if ($_ eq $self->{tag_to});
+	}
+	unless ($found) {
 		$self->{mw}->messageBox(
 				-message	=> "$self->{tag_from} >= $self->{tag_to}",
 				-icon		=> 'error',
